import pandas as pd
import numpy as np
import yaml

import os.path

from scipy.signal import savgol_filter


def load_data_RH_logger(filepath, every=1):
    """

    """
    with open(filepath, 'r') as f:
        header = f.readline()
    header = header.strip('# ').rstrip('\n').split('|')
    header.append('X') # Empty col...

    df = pd.read_csv(filepath, sep=' ',  names=header, skiprows=1)
    df = df.drop(columns='X')
    df = df.drop(np.arange(1))

    df['dm_m'] = (df['weight'] - df['weight'].iloc[0]) / df['weight'].iloc[0]

    # Crop data
    df = df.reset_index()
    del df['index']

    # Derivative
    df['dmdt'] = savgol_filter(df['weight'], window_length=10000, polyorder=1, deriv=1)

    return df.iloc[::every]


def process_data_RH_logger(filepath):
    df = load_data_RH_logger(filepath, every=1)
    h5path = os.path.splitext(filepath)[0]
    h5path += '-processed.h5'
    df.to_hdf(h5path, key='data')


def load_metadata(filepath):
    """

    """
    with open(filepath, 'r') as stream:
        metadata = yaml.safe_load(stream)
    return metadata
